commit 015642fb58fde0be1aa9be3801d5abec277326ae
Author: Leszek Koltunski <leszek@distoretedandroid.org>
Date:   Tue Jun 21 11:06:03 2016 +0100

    Cleanup.

diff --git a/src/main/java/org/distorted/library/DistortedBitmap.java b/src/main/java/org/distorted/library/DistortedBitmap.java
index 37a64fe..606ed64 100644
--- a/src/main/java/org/distorted/library/DistortedBitmap.java
+++ b/src/main/java/org/distorted/library/DistortedBitmap.java
@@ -100,7 +100,7 @@ public class DistortedBitmap extends DistortedObject
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 /**
- * {@see DistortedObject#DistortedObject(DistortedObject,flags)}
+ * {@see DistortedObject#DistortedObject(DistortedObject,int)}
  */
    public DistortedBitmap(DistortedBitmap db, int flags)
      {
diff --git a/src/main/java/org/distorted/library/DistortedCubes.java b/src/main/java/org/distorted/library/DistortedCubes.java
index 3b5a42b..ac58e85 100644
--- a/src/main/java/org/distorted/library/DistortedCubes.java
+++ b/src/main/java/org/distorted/library/DistortedCubes.java
@@ -54,7 +54,7 @@ public class DistortedCubes extends DistortedObject
  * @param cols Integer helping to parse the next parameter.
  * @param desc String describing the subset of a MxNx1 cuboid that we want to create.
  *             Its MxN characters - all 0 or 1 - decide of appropriate field is taken or not.
- *
+ *             <p>
  *             For example, (cols=2, desc="111010") describes the following shape:
  *
  *             XX
@@ -66,7 +66,7 @@ public class DistortedCubes extends DistortedObject
  *             XX
  *
  *              X
- *
+ *             </p>
  * @param gridSize size, in pixels, of the single 1x1x1 cube our cuboid is built from
  * @param frontOnly Only create the front wall or side and back as well?
  */
@@ -111,7 +111,7 @@ public class DistortedCubes extends DistortedObject
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 /**
- * {@see DistortedObject#DistortedObject(DistortedObject,flags)}
+ * {@see DistortedObject#DistortedObject(DistortedObject,int)}
  */
  public DistortedCubes(DistortedCubes dc, int flags)
    {
diff --git a/src/main/java/org/distorted/library/DistortedNode.java b/src/main/java/org/distorted/library/DistortedNode.java
index 0e35aff..4d4fbec 100644
--- a/src/main/java/org/distorted/library/DistortedNode.java
+++ b/src/main/java/org/distorted/library/DistortedNode.java
@@ -353,7 +353,7 @@ public class DistortedNode
  *     
  * @param node The DistortedNode to copy data from.
  * @param flags bit field composed of a subset of the following:
- *        {@link Distorted#CLONE_BITMAP},  {@link Distorted#CLONE_PRESHADER}, {@link Distorted#CLONE_VERTEX},
+ *        {@link Distorted#CLONE_BITMAP},  {@link Distorted#CLONE_MATRIX}, {@link Distorted#CLONE_VERTEX},
  *        {@link Distorted#CLONE_FRAGMENT} and {@link Distorted#CLONE_CHILDREN}.
  *        For example flags = CLONE_BITMAP | CLONE_CHILDREN.
  */
diff --git a/src/main/java/org/distorted/library/DistortedObject.java b/src/main/java/org/distorted/library/DistortedObject.java
index a8d3fba..a196662 100644
--- a/src/main/java/org/distorted/library/DistortedObject.java
+++ b/src/main/java/org/distorted/library/DistortedObject.java
@@ -28,7 +28,6 @@ import org.distorted.library.type.Data1D;
 import org.distorted.library.type.Data2D;
 import org.distorted.library.type.Data3D;
 import org.distorted.library.type.Data4D;
-import org.distorted.library.type.Static2D;
 import org.distorted.library.type.Static3D;
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
@@ -79,7 +78,7 @@ public abstract class DistortedObject
     
   protected void initializeEffectLists(DistortedObject d, int flags)
     {
-    if( (flags & Distorted.CLONE_PRESHADER) != 0 )
+    if( (flags & Distorted.CLONE_MATRIX) != 0 )
       {
       mM = d.mM;
       matrixCloned = true;

diff --git a/src/main/java/org/distorted/library/Distorted.java b/src/main/java/org/distorted/library/Distorted.java
index a3b261f..ae0e8e7 100644
--- a/src/main/java/org/distorted/library/Distorted.java
+++ b/src/main/java/org/distorted/library/Distorted.java
@@ -51,13 +51,13 @@ public class Distorted
    */
   public static final int CLONE_BITMAP  = 0x1;
   /**
    * When creating an instance of a DistortedObject from another instance, clone the PreShader Effects.
    * <p>
    * This way we can have two different DistortedObjects with different Bitmaps behind them, both 
    * always displayed in exactly the same place on the screen. Applying any matrix-based effect to 
    * one of them automatically applies the effect to the other. Used in the copy constructor.
    */
-  public static final int CLONE_PRESHADER = 0x2;
+  public static final int CLONE_MATRIX = 0x2;
   /**
    * When creating an instance of a DistortedObject from another instance, clone the Vertex Effects.
    * <p>
@@ -74,11 +74,6 @@ public class Distorted
    * applies the effect to the other. Used in the copy constructor.
    */
   public static final int CLONE_FRAGMENT= 0x8;
-
-  // Note: why no 'CLONE_POSTSHADER' constant? The only Postshader effects are the 'save to PNG file'
-  // 'save to MP4 file'. Sharing those effects across multiple DistortedObject objects does not make any
-  // sense - multiple Objects would then fight to get saved all to the same file.
-
   /**
    * When creating an instance of a DistortedNode from another instance, clone the children Nodes.
    * <p>
@@ -313,7 +308,7 @@ public class Distorted
  * Compiles the vertex and fragment shaders, establishes the addresses of all uniforms, and initialises all Bitmaps that have already
  * been created.
  *   
- * @param context Context of the APpp using the library - used to open up Resources and read Shader code.
+ * @param context Context of the App using the library - used to open up Resources and read Shader code.
  * @throws FragmentCompilationException
  * @throws VertexCompilationException
  * @throws VertexUniformsException
@@ -51,13 +51,13 @@ public class Distorted
   public static final int CLONE_BITMAP  = 0x1;
   /**
-   * When creating an instance of a DistortedObject from another instance, clone the PreShader Effects.
+   * When creating an instance of a DistortedObject from another instance, clone the Matrix Effects.
    * <p>
    * This way we can have two different DistortedObjects with different Bitmaps behind them, both 